import ast,os

class NonDeterministicFunctionChecker:
    name = 'flake8_checker'
    version = '1.0.0'

    def __init__(self, tree, filename,config=None):
        self.tree = tree

    def run(self):
        visitor = NonDeterministicFunctionVisitor()
        visitor.visit(self.tree)
        for lineno, column, msg in visitor.messages:
            yield (lineno, column, msg, NonDeterministicFunctionChecker)


class NonDeterministicFunctionVisitor(ast.NodeVisitor):
    NON_DETERMINISTIC_FUNCTIONS = os.environ.get('NON_DETERMINISTIC_FUNCTIONS', '')

    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)
        self.messages = []
 
    def visit_Call(self, node):
        function_name = self.get_function_name(node)
        if function_name in self.NON_DETERMINISTIC_FUNCTIONS:
            msg = 'ND001 Non-deterministic function "{}" used'.format(function_name)
            self.messages.append((node.lineno, node.col_offset, msg))

    def get_function_name(self, node):
        if isinstance(node.func, ast.Name):
            return node.func.id
        elif isinstance(node.func, ast.Attribute):
            return node.func.attr
        return None



import setuptools

setuptools.setup(
   name='flake8-checker',
   version='0.0.1',
   description='Plugin to comply with my picky standards',
   author='Harish, Dasika',
   author_email='harish.dasika@gmail.com',
   py_modules=['flake8_checker'],
   entry_points={
       'flake8.extension': [
           'ND001 = flake8_checker:NonDeterministicFunctionChecker',
       ],
   },
   install_requires=['flake8'],
   classifiers=[
       'Development Status :: 3 - Alpha',
   ],
)